from setuptools import setup

setup(
    name='labypy',
    version='1.4.4',
    packages=['labypy'],
    license='MIT',
    author='Zyking',
    description='A Labymod Cosmetics Library',
    install_requires=[
        "requests",
    ],
)